%define ALD_Ver		1.2.1

%define OrgName pkg-config

License:      GPL
Summary:      This is pkg-config
Group:        System Environment/Libraries
Version:      0.25
Release:      3

Source: %{OrgName}-%{version}.tar.xz
Patch0: %{OrgName}-%{version}.patch
Patch1: %{OrgName}-%{version}.x86_64.patch
Patch2: %{OrgName}-%{version}.arm.patch

%define DestDir		/Compiler
# -----------------------------------------------------
%if %{_target_cpu} == %{_build_cpu}
%define _CROSS 0
%define BUILD_LOCAL_CROSS 0
%else
# rpm --target=x86_64 -ba xxxxx.spec
%define _CROSS 1
%define BUILD_LOCAL_CROSS 0
%endif

%define TO_ARCH %{_target_cpu}

%if %{_target_cpu} == "armv6l"
%define ARM_ARCH armv6zk
%define ARM_FPU  -mfpu=vfp -mfloat-abi=hard
%define TO_ARCH %{ARM_ARCH}
%endif

%if %{_target_cpu} == "armv7l"
%define ARM_ARCH armv7-a
%define ARM_FPU  -mfpu=vfpv3-d16 -mfloat-abi=hard
%define TO_ARCH %{ARM_ARCH}
%endif

%define BUILD_TAR 1
# -----------------------------------------------------
%if %{BUILD_LOCAL_CROSS}
Name:         %{OrgName}-%{TO_ARCH}
%else
Name:         %{OrgName}
%endif

#------------------ CROSS DIR --------------------
%if %{_CROSS}

%if %{_os} == "mingw"
#ERROR: target=%{_os}
%else  #win32 || win64
%define target %{_arch}-%{_os}%{_gnu}
%endif

%define crossdir	/cross
%if %{_arch} == "arm"
%define csysdir		%{crossdir}/%{ARM_ARCH}
%else
%define csysdir		%{crossdir}/%{_target_cpu}
%endif
%define csysbindir	%{csysdir}/bin

%if %{BUILD_LOCAL_CROSS}
%define _prefix		%{csysdir}
%define CrossDestDir	/Cross
%else
%define CrossDestDir %{nil}
%endif

%if !%{BUILD_LOCAL_CROSS}
%define __os_install_post \
    %{csysbindir}/rpm/brp-strip \
    %{csysbindir}/rpm/brp-strip-static-archive \
    %{csysbindir}/rpm/brp-strip-comment-note \
    %{_rpmconfigdir}/brp-compress \
%{nil}
%endif #BUILD_LOCAL_CROSS

%define _srcrpmdir %{_topdir}/SRPMS/tmp

%else  #_CROSS

%define csysbindir	%{_prefix}/bin
%define CrossDestDir %{nil}
%define _srcrpmdir %{_topdir}/SRPMS/%{ALD_Ver}

%define target %{_arch}-uclibc

%endif # !_CROSS

%define docdir %{_defaultdocdir}/%{OrgName}

# ------------------- description ------------------------------------
%description
pkg-config is a script to make putting together all the build
flags when compiling/linking a lot easier.

# ------------------- setup ------------------------------------------
%Prep
%setup -q -n %{OrgName}-%{version}
%patch0 -b .orig -p0
%if %{_CROSS}
%if %{_arch} == "x86_64"
%patch1 -b .orig -p0
%endif
%if %{_arch} == "arm"
%patch2 -b .orig -p0
%endif
%endif # _CROSS

# ------------------- Build ------------------------------------------
%Build
%if %{_CROSS}
PATH=%{csysbindir}:$PATH:/opt/perl/bin
GCC_NoHostPath=d
export PATH GCC_NoHostPath
%else
export PATH=$PATH:/opt/perl/bin
%endif

%if %{BUILD_LOCAL_CROSS}
%if %{_build_cpu} == "i386"
OPTFLAGS="-Os -march=i486 -mpreferred-stack-boundary=2 -falign-functions=1 -falign-jumps=1 -falign-loops=1 -fomit-frame-pointer"
%endif
%if (%{_build_cpu} == "x86_64") || (%{_build_cpu} == "win64") 
OPTFLAGS="-Os -fno-asynchronous-unwind-tables"
%endif
%if (%{_build_cpu} == "armv6l") || (%{_build_cpu} == "armv7l")
OPTFLAGS="-Os -march=%{ARM_ARCH} %{ARM_FPU} -munaligned-access"
%endif
%else
%if %{_arch} == "i386"
OPTFLAGS="-Os -march=i486 -mpreferred-stack-boundary=2 -falign-functions=1 -falign-jumps=1 -falign-loops=1 -fomit-frame-pointer"
%endif
%if %{_arch} == "x86_64"
OPTFLAGS="-Os -fno-asynchronous-unwind-tables"
%endif
%if %{_arch} == "arm"
OPTFLAGS="-Os -march=%{ARM_ARCH} %{ARM_FPU} -munaligned-access"
%endif
%endif

CFLAGS="$OPTFLAGS -ffunction-sections -fdata-sections -fno-tree-loop-optimize -fno-tree-dominator-opts -fno-strength-reduce -fno-stack-protector"
LDFLAGS="-Wl,--gc-sections"

#glib_cv_sizeof_gmutex=24
#glib_cv_byte_contents_gmutex=0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
#export glib_cv_sizeof_gmutex glib_cv_byte_contents_gmutex

%configure \
	--build=%{_build} \
%if %{_CROSS} && !%{BUILD_LOCAL_CROSS}
	--host=%{target} \
%endif
	--without-debug \
	--enable-debug=no \
%if %{BUILD_LOCAL_CROSS}
	--with-pc-path=%{_prefix}/usr/%{_lib}/pkgconfig:%{_prefix}/usr/X11/%{_lib}/pkgconfig:%{_prefix}/usr/share/pkgconfig \
%else
	--with-pc-path=%{_prefix}/%{_lib}/pkgconfig:%{_prefix}/X11/%{_lib}/pkgconfig:%{_prefix}/share/pkgconfig \
%endif
	--enable-threads=no \
	--with-threads=none \
	&>FConfigure_log.txt

make &>FMake_log.txt

# ------------------- Install ----------------------------------------
%Install
%if %{_CROSS}
PATH=%{csysbindir}:$PATH:/opt/perl/bin
GCC_NoHostPath=d
export PATH GCC_NoHostPath
%else
export PATH=$PATH:/opt/perl/bin
%endif

rm -rf $RPM_BUILD_ROOT
mkdir -p $RPM_BUILD_ROOT
mkdir -p %{_srcrpmdir}

make DESTDIR=$RPM_BUILD_ROOT install

%if %{BUILD_LOCAL_CROSS}
pushd $RPM_BUILD_ROOT%{_bindir}
  ln -s pkg-config %{target}-pkg-config
popd
rm -r $RPM_BUILD_ROOT%{_mandir}
mkdir -p $RPM_BUILD_ROOT%{_prefix}/usr
mv $RPM_BUILD_ROOT%{_prefix}/share $RPM_BUILD_ROOT%{_prefix}/usr/
%endif

%if !%{_CROSS}
if test -f /opt/aldccp/bin/packages_idx; then
  /opt/aldccp/bin/packages_idx -p %{name} -v %{version} $RPM_BUILD_ROOT
fi
%endif

# ------------------- Clean ------------------------------------------
%Clean 

%if %{BUILD_LOCAL_CROSS}
  DE=%{version}-%{release}.%{_build_cpu}.rpm
  DD=%{_rpmdir}/%{_build_cpu}/%{ALD_Ver}%{CrossDestDir}/%{TO_ARCH}%{DestDir}
%else  #%{BUILD_LOCAL_CROSS}
  DE=%{version}-%{release}.%{TO_ARCH}.rpm
  DD=%{_rpmdir}/%{TO_ARCH}/%{ALD_Ver}%{CrossDestDir}%{DestDir}
%endif #!%{BUILD_LOCAL_CROSS}

pushd %{_rpmdir}/%{_target_cpu}
  SE=%{version}-%{release}.%{_target_cpu}.rpm
  mkdir -p $DD
  mv %{name}-$SE $DD/%{name}-$DE
popd

%if %{BUILD_TAR}
# --------------- build *.tgz ------------------------
pushd $RPM_BUILD_ROOT
  TMP_TO=$DD/tar
  mkdir -p $TMP_TO
  tmp=%{name}-%{version}-%{release}
  mkdir -p $tmp
%if %{BUILD_LOCAL_CROSS}
  cp -r cross $tmp/
%else
  cp -r usr $tmp/
%endif
  tar -cjf $tmp.tar.bz2 $tmp
  mv $tmp.tar.bz2 $TMP_TO
  rm -r $tmp
popd
%endif  #BUILD_LOCAL_CROSS

# ------------------- Files ------------------------------------------
%Files
%{_prefix}
